# -*- coding: utf-8 -*-
#Copyright (C) 2010, 2011 Seán Hayes
#
#Licensed under a BSD 3-Clause License. See LICENSE file.

VERSION = (1, 0, 6)

__version__ = "".join([".".join(map(str, VERSION[0:3])), "".join(VERSION[3:])])
